/*
 Calibration for Squishy Button
 
 Demonstrates one technique for calibrating sensor input.  The
 sensor readings during the first five seconds of the sketch
 execution define the minimum and maximum of expected values
 attached to the sensor pin.
 
 The sensor minimum and maximum initial values may seem backwards.
 Initially, you set the minimum high and listen for anything 
 lower, saving it as the new minimum. Likewise, you set the
 maximum low and listen for anything higher as the new maximum.
 
 The circuit:
 * Squish sensor attached to analog input 0
 
 created 29 Oct 2008
 By David A Mellis
 modified 30 Aug 2011
 By Tom Igoe
 adapted 28 May 2013
 By Bruno Nadeau

 This example code is in the public domain.
 
 */

// These constants won't change:
const int sensorPin = A0;    // pin that the sensor is attached to

// variables:
int sensorValue = 0;         // the sensor value
int sensorMin = 1023;        // minimum sensor value
int sensorMax = 0;           // maximum sensor value
boolean squished = false;    // true when the button is pressed

void setup() {
  Serial.begin(9600);
  Serial.println("Start calibration...");
  
  // calibrate during the first five seconds 
  while (millis() < 5000) {
    sensorValue = analogRead(sensorPin);

    // record the maximum sensor value
    if (sensorValue > sensorMax) {
      sensorMax = sensorValue;
    }

    // record the minimum sensor value
    if (sensorValue < sensorMin) {
      sensorMin = sensorValue;
    }
  }

  Serial.print("Min: ");
  Serial.println(sensorMin);
  Serial.print("Max: ");
  Serial.println(sensorMax);
}

void loop() {
  // read the sensor:
  sensorValue = analogRead(sensorPin);
  
  if (sensorValue > (sensorMax+sensorMin)/2) {
    if (!squished) {
      squished = true;
      Serial.println("squished!");
    }
  }
  else {
    squished = false;
  }
}
